## aman.spec.in
##
##    The Aman Rivendell Server Manager
##    Copyright (C) 2012-2022  Fred Gleason <fredg@paravelsystems.com>
##
##    This program is free software; you can redistribute it and/or modify
##    it under the terms of version 2 of the GNU General Public License as
##    published by the Free Software Foundation;
##
##    This program is distributed in the hope that it will be useful,
##    but WITHOUT ANY WARRANTY; without even the implied warranty of
##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##    GNU General Public License for more details.
##
##    You should have received a copy of the GNU General Public License
##    along with this program; if not, write to the Free Software
##    Foundation, Inc., 59 Temple Place, Suite 330, 
##    Boston, MA  02111-1307  USA
##

Summary: Rivendell Server Manager System
Name: aman
Version: 0.10.1
Release: 1%{?dist}
License: GPL
Packager: Fred Gleason <fredg@paravelsystems.com>
Group: Productivity/Multimedia/Other
Source: %{name}-0.10.1.tar.gz
Requires: mariadb-server qt5-qtbase-mysql  rsync perl-TermReadKey perl-DBD-MySQL bzip2
BuildRoot: /var/tmp/%{name}-0.10.1
Conflicts: aman-remote

%description
Aman is a package for managing a redundant pair of servers for the
Rivendell Radio Automation System.  It includes facilities for monitoring
the status of each server and managing data replication between them for
both the database and audio stores.

%package remote
Summary: Allow an additional systemto replicate from an Aman cluster
Group: Productivity/Multimedia/Other
Requires: qt5-qtbase-mysql rsync bzip2
Conflicts: aman

%description remote
This package allows a third system to replicate data (database and audio) from
an Aman server cluster.

%prep


%setup


%build
%configure
make


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/var/aman/keys
mkdir -p $RPM_BUILD_ROOT/var/aman/snapshots
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la


%post
ldconfig
if test "redhat" = "suse" ; then
  PACKAGE_DOC_DIR=%_docdir/%{name}
fi
if test "redhat" = "redhat" ; then
  PACKAGE_DOC_DIR=%_docdir/%{name}-0.10.1
fi
if test ! -e /etc/aman.conf ; then
  cp $PACKAGE_DOC_DIR/aman.conf-sample /etc/aman.conf
fi
if test ! -e /etc/rsyncd.conf ; then
  cp $PACKAGE_DOC_DIR/rsyncd.conf-sample /etc/rsyncd.conf
fi
/bin/systemctl daemon-reload
/bin/systemctl enable aman
/bin/systemctl start aman
if [ -x %{_bindir}/gtk-update-icon-cache ] ; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi
exit 0

%preun
if test "$1" = "0" ; then
  /bin/systemctl stop aman
  /bin/systemctl disable aman
fi
exit 0


%postun
/bin/systemctl daemon-reload
if [ -x %{_bindir}/gtk-update-icon-cache ] ; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi
exit 0


%post remote
ldconfig
if test "redhat" = "suse" ; then
  PACKAGE_DOC_DIR=%_docdir/%{name}
fi
if test "redhat" = "redhat" ; then
  PACKAGE_DOC_DIR=%_docdir/%{name}-0.10.1
fi
if test ! -e /etc/amanrmt.conf ; then
  cp $PACKAGE_DOC_DIR/amanrmt.conf-sample /etc/amanrmt.conf
fi
if [ -x %{_bindir}/gtk-update-icon-cache ] ; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi


%postun remote
if [ -x %{_bindir}/gtk-update-icon-cache ] ; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi


%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{_libdir}/libaman-0.10.1.so
%{_libdir}/libaman.so
%{_bindir}/aman
%{_bindir}/aman-root
%{_bindir}/aman_add_rivendell_user.pl
%{_bindir}/aman_add_replication_users.pl
%{_bindir}/aman_add_remote_replication_user.pl
%{_sbindir}/amanctl
%{_sbindir}/amand
/usr/lib/systemd/system/aman.service
/etc/pam.d/aman-root
/etc/security/console.apps/aman-root
/etc/security/limits.d/aman-mysql-limits.conf
/usr/share/icons/hicolor/16x16/apps/aman.png
/usr/share/icons/hicolor/22x22/apps/aman.png
/usr/share/icons/hicolor/32x32/apps/aman.png
/usr/share/icons/hicolor/48x48/apps/aman.png
/usr/share/applications/aman-aman.desktop
%{_mandir}/man8/amanctl.8.gz
%dir /var/aman/keys
%dir /var/aman/snapshots
%doc AUTHORS
%doc ChangeLog
%doc COPYING 
%doc INSTALL
%doc NEWS 
%doc README 
%doc conf/aman.conf-sample
%doc conf/aman.cnf-SystemA-rhel7-sample
%doc conf/aman.cnf-SystemB-rhel7-sample
%doc conf/rsyncd.conf-sample
%doc docs/command_protocol.txt

%files remote
%defattr(-,root,root)
%{_libdir}/libaman-0.10.1.so
%{_libdir}/libaman.so
%{_bindir}/amanrmt
%{_bindir}/amanrmt-root
/etc/pam.d/amanrmt-root
/etc/security/console.apps/amanrmt-root
/usr/share/icons/hicolor/16x16/apps/aman.png
/usr/share/icons/hicolor/22x22/apps/aman.png
/usr/share/icons/hicolor/32x32/apps/aman.png
/usr/share/icons/hicolor/48x48/apps/aman.png
/usr/share/applications/aman-amanrmt.desktop
%dir /var/aman/keys
%dir /var/aman/snapshots
%doc AUTHORS
%doc ChangeLog
%doc COPYING 
%doc INSTALL
%doc NEWS 
%doc README 
%doc conf/amanrmt.conf-sample
%doc conf/aman.cnf-remote-rhel7-sample

%changelog
* Mon May  9 2022 Fred Gleason <fredg@paravelsystems.com>
-- Removed docs/mysql_states.gxd.
-- Added '/usr/bin/aman_add_remote_replication_user.pl'.
-- Added '/usr/share/doc/aman/aman.cnf-remote-rhel7-sample
* Thu Apr  7 2022 Fred Gleason <fredg@paravelsystems.com>
-- Added amanrmt(1).
* Mon Nov  1 2021 Fred Gleason <fredg@paravelsystems.com>
-- Converted to use Qt5.
-- Converted startup system to Systemd.
* Fri Jul 21 2017 Fred Gleason <fredg@paravelsystems.com>
-- Added a 'bzip2' dependency.
* Thu Jun 29 2017 Fred Gleason <fredg@paravelsystems.com>
-- Added amanctl(8).
* Sat Feb 18 2017 Fred Gleason <fredg@paravelsystems.com>
-- Added 'Added sample configs for MariaDB on CentOS 7.
* Tue Jul  2 2013 Fred Gleason <fredg@paravelsystems.com>
-- Added 'rsync.xinetd-sample'.
* Tue Jun 25 2013 Fred Gleason <fredg@paravelsystems.com>
-- Added 'mysql-server' and 'rsync' dependencies.
-- Added 'INSTALL' to the documentation directory.
-- Added 'aman-mysql-limits.conf'.
-- Added 'perl-TermReadKey' dependency.
-- Added 'perl-DBD-MySQL' dependency.
-- Added 'aman_add_rivendell_user.pl'.
* Mon Jun 17 2013 Fred Gleason <fredg@paravelsystems.com>
-- Initial package.
